@@ -5,6 +5,7 @@ from .models import Warning
 from .models import WaringCategory
 
 from .actions import django_site_warnings_acknowledge
+from .actions import django_site_warnings_deny
 
 class WaringCategoryAdmin(admin.ModelAdmin):
     list_display = ["name", "code"]
@@ -21,6 +22,7 @@ class WarningAdmin(admin.ModelAdmin):
 
     actions = [
         django_site_warnings_acknowledge,
+        django_site_warnings_deny,
     ]
 
     
