@@ -5,7 +5,7 @@ from django.utils.translation import ugettext_lazy as _
 from django.utils import timezone
 
 
-from django_simpletask.models import SimpleTask
+from django_simpletask2.models import SimpleTask
 from django_safe_fields.fields import SafeCharField
 from django_safe_fields.fields import SafeTextField
 
@@ -24,6 +24,8 @@ class WaringCategory(models.Model):
 
     @classmethod
     def get(cls, code):
+        if isinstance(code, WaringCategory):
+            return code
         try:
             return cls.objects.get(code=code)
         except cls.DoesNotExist:
@@ -31,6 +33,9 @@ class WaringCategory(models.Model):
 
 
 class Warning(SimpleTask):
+
+    send_notify = None
+
     category = models.ForeignKey(WaringCategory, on_delete=models.SET_NULL, null=True, blank=True, verbose_name=_("Warning Category"))
     title = SafeCharField(max_length=1024, verbose_name=_("Warning Title"))
     data = SafeTextField(null=True, blank=True, verbose_name=_("Warning Data"))
@@ -44,6 +49,15 @@ class Warning(SimpleTask):
     def __str__(self):
         return self.title
 
+    @classmethod
+    def register_send_notify(cls, send_notify):
+        cls.send_notify = send_notify
+
+    def do_task_main(self, payload=None, force=False):
+        if self.send_notify:
+            self.send_notify(self)
+        return True
+
     @classmethod
     def make(cls, category, title, data=None, save=False):
         category = WaringCategory.get(category)
@@ -81,4 +95,10 @@ class Warning(SimpleTask):
         self.ack_time = timezone.now()
         if save:
             self.save()
-        
\ No newline at end of file
+    
+    def deny(self, save=True):
+        self.ack = False
+        self.ack_time = None
+        if save:
+            self.save()
+
